@@ -64,22 +64,23 @@ sub content {
     return $content;
 }
 
-sub has_portfile {
-    my $self = shift;
-
-}
-
 sub has_makefile {
     my $self = shift;
-
-
+    my @files = $self->archive->files();
+    @files = grep /makefile/i , @files;
+    return @files if scalar @files;
+    return undef;
 }
 
-# vimball
-sub vba_install {
-
+sub has_vimball {
+    my $self = shift;
+    my @files = $self->archive->files();
+    @files = grep /\.vba$/i , @files;
+    return @files if scalar @files;
+    return undef;
 }
 
+
 sub auto_install {
     my $self = shift;
     my %args = @_;
@@ -90,4 +91,9 @@ sub auto_install {
 
 }
 
+
+sub makefile_install {
+
+}
+
 1;
